# fmplib
Python library to fetch data from [Financial Modeling Prep](https://site.financialmodelingprep.com/).

## Installation
To install fmplib from source :

Clone repo then use pip :
``` {.sourceCode .bash}
$ pip install .
```

To access FMP API you'll need to create a .env file and set your API key in the following env variable FMP_API_KEY.
Exemple : FMP_API_KEY=xx_yourapikey_xx

